@@ -3,10 +3,10 @@ function(nodes=100,arcs=300,max.weight=10,directed=TRUE,seed=NULL){
   #If seed is set, set if formally
   if (!is.null(seed))
     set.seed(as.integer(seed))
-  #Create random edgelist object with 33% more ties than needed
-  rg_w <- data.frame(i=sample(1:nodes, (arcs*1.33), replace=TRUE), 
-                   j=sample(1:nodes, (arcs*1.33), replace=TRUE),
-                   w=sample(1:max.weight, (arcs*1.33), replace=TRUE))
+  #Create random edgelist object with 5% more ties than needed
+  rg_w <- data.frame(i=sample(1:nodes, (arcs*1.5), replace=TRUE), 
+                     j=sample(1:nodes, (arcs*1.5), replace=TRUE),
+                     w=sample(1:max.weight, (arcs*1.5), replace=TRUE))
   #Remove self-loops
   rg_w <- rg_w[rg_w[,1]!=rg_w[,2],]
   #Remove duplicated entries
@@ -22,8 +22,5 @@ function(nodes=100,arcs=300,max.weight=10,directed=TRUE,seed=NULL){
     rg_w <- rbind(cbind(rg_w[,1],rg_w[,2],rg_w[,3]), 
                   cbind(rg_w[,2],rg_w[,1],rg_w[,3]))
   }
-  rg_w <- rg_w[order(rg_w[,1], rg_w[,2]),]
-  dimnames(rg_w)[[2]]<-c("i","j","w")
-  rownames(rg_w)<-NULL
-  return(rg_w)
+  return(as.tnet(rg_w, type="weighted one-mode tnet"))
 }
\ No newline at end of file
